@@ -13,7 +13,7 @@ pub mod shard_format;
 pub mod shard_in_memory;
 pub mod utils;
 
-pub use constants::{hash_is_global_dedup_eligible, MDB_SHARD_TARGET_SIZE};
+pub use constants::{MDB_SHARD_TARGET_SIZE, hash_is_global_dedup_eligible};
 pub use shard_file_handle::MDBShardFile;
 pub use shard_file_manager::ShardFileManager;
 pub use shard_format::{MDBShardFileFooter, MDBShardFileHeader, MDBShardInfo};
